import datetime
from ...convert import SystemMode

RAW_V1 = {
    "Date": "03.05.2020",
    "Time": "20:56:38",
    "DeviceName": "ECFABC0D1111",
    "MAC": "A020A6199C99",
    "LocalIP": "192.168.178.137",
    "RSSI": "-60",
    "FW_MainController": "1838000A",
    "FW_WiFi": "WS181130",
    "SystemMode": "Kellermode",
    "Speed_In": "01",
    "Speed_Out": "01",
    "Speed_AntiFreeze": "00",
    "Temp_In": "0,0",
    "Temp_Out": "18,6",
    "Temp_Fresh": "18,6",
    "rel_Humidity_In": "0,0",
    "rel_Humidity_Out": "77,7",
    "abs_Humidity_In": "0,0",
    "abs_Humidity_Out": "12,4",
    "Efficiency": "N/A",
    "Humidity_Transport": "-1485",
    "_SystemOn": "1",
    "_FrostschutzAktiv": "0",
    "_Frozen": "0",
    "_AbtauMode": "0",
    "_VermieterMode": "0",
    "_QuerlueftungAktiv": "0",
    "_MaxMode": "0",
}

PROCESSED_V1 = {
    "Date": datetime.date(2020, 5, 3),
    "Time": datetime.time(20, 56, 38),
    "DeviceName": "ECFABC0D1111",
    "MAC": "0xa020a6199c99",
    "LocalIP": "192.168.178.137",
    "RSSI": -60,
    "FW_MainController": "1838000A",
    "FW_WiFi": "WS181130",
    "SystemMode": SystemMode.Kellermode,
    "Speed_In": 1,
    "Speed_Out": 1,
    "Speed_AntiFreeze": 0,
    "Temp_In": 0.0,
    "Temp_Out": 18.6,
    "Temp_Fresh": 18.6,
    "rel_Humidity_In": 0.0,
    "rel_Humidity_Out": 77.7,
    "abs_Humidity_In": 0.0,
    "abs_Humidity_Out": 12.4,
    "Efficiency": None,
    "Humidity_Transport": -1485,
    "_SystemOn": True,
    "_FrostschutzAktiv": False,
    "_Frozen": False,
    "_AbtauMode": False,
    "_VermieterMode": False,
    "_QuerlueftungAktiv": False,
    "_MaxMode": False,
}

RAW_V2 = {
    "Date": "11.09.2023",
    "Time": "06:30:36",
    "DeviceName": "3485185xxxxx",
    "MAC": "000000000000",
    "LocalIP": "192.168.0.0",
    "RSSI": "-82",
    "FW_MainController": "Rev2.1",
    "FW_WiFi": "WS32233602",
    "SystemMode": "Zeitgesteuert",
    "_SystemOn": "0",
    "Speed_In": "00",
    "Speed_Out": "00",
    "Speed_AntiFreeze": "00",
    "Temp_In": "0,0",
    "Temp_Out": "0,0",
    "Temp_Fresh": "21,8",
    "rel_Humidity_In": "0,0",
    "rel_Humidity_Out": "0,0",
    "abs_Humidity_In": "0,0",
    "abs_Humidity_Out": "0,0",
    "Efficiency": "N/A",
    "Humidity_Transport": "0",
}

PROCESSED_V2 = {
    "Date": datetime.date(2023, 9, 11),
    "Time": datetime.time(6, 30, 36),
    "DeviceName": "3485185xxxxx",
    "MAC": hex(0x000000000000),
    "LocalIP": "192.168.0.0",
    "RSSI": -82,
    "FW_MainController": "Rev2.1",
    "FW_WiFi": "WS32233602",
    "SystemMode": SystemMode.Zeitgesteuert,
    "_SystemOn": False,
    "Speed_In": 0,
    "Speed_Out": 0,
    "Speed_AntiFreeze": 0,
    "Temp_In": 0.0,
    "Temp_Out": 0.0,
    "Temp_Fresh": 21.8,
    "rel_Humidity_In": 0.0,
    "rel_Humidity_Out": 0.0,
    "abs_Humidity_In": 0.0,
    "abs_Humidity_Out": 0.0,
    "Efficiency": None,
    "Humidity_Transport": 0,
}
